Triangle class

A minimal Triangle class compatible with vector_math

Constructors

Triangle.points(Vector3 point0, Vector3 point1, Vector3 point2)
Create a triangle from three vertices, but don't set the normal

Properties

hashCode int
The hash code for this object.
no setterinherited
normal Vector3
Surface normal of the triangle
getter/setter pair
point0 Vector3
The three vertices of the triangle
final
point1 Vector3
The three vertices of the triangle
final
point2 Vector3
The three vertices of the triangle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyNormalInto(Vector3 normal) → void
Copy the normal of the triangle into a Vector3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited