loadSTLFile static method

List<Triangle>? loadSTLFile(
  1. File f
)

Load a STL file This function takes a file parameter f and returns List of triangles, or null on error

Implementation

static List<Triangle>? loadSTLFile(File f) {
  var fileContent = f.readAsStringSync();
  return fromSTL(fileContent);
}