StlToken enum
These are the tokens that make up an ASCII STL file
Values
- solid → const StlToken
-
Start of a solid
- endSolid → const StlToken
-
End of a solid
- facet → const StlToken
-
Start of a facet
- endFacet → const StlToken
-
End of a facet
- loop → const StlToken
-
Start of a loop
- endLoop → const StlToken
-
End of a loop
- vertex → const StlToken
-
Vertex
- error → const StlToken
-
A token to indicate a parse error occurred
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited