Vector3 class
A minimal Vector3 class compatible with vector_math
Constructors
- Vector3(double x, double y, double z)
- Create a vector
- Vector3.zero()
- Create a zero vector
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → double
-
Compute the legnth of the vector
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x ↔ double
-
The components of the vector
getter/setter pair
- y ↔ double
-
The components of the vector
getter/setter pair
- z ↔ double
-
The components of the vector
getter/setter pair
Methods
-
cross(
Vector3 other) → Vector3 - Compute the cross product of two vectors
-
normalize(
) → void - Normalize the vector
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setFrom(
Vector3 other) → void - Assignment operator
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator -(
Vector3 other) → Vector3 - Negation operator
-
operator ==(
Object other) → bool -
The equality operator.
override