StlReader class
A class for loading ASCII STL data from files or Strings
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromSTL(
String fileContent) → List< Triangle> ? -
Create a list of triangles from a String containing
a valid STL file
This function takes a string parameter
fileContentand returns List of triangles, or null on error -
loadSTLFile(
File f) → List< Triangle> ? -
Load a STL file
This function takes a file parameter
fand returns List of triangles, or null on error